# Bilingual Conversation Bot

This Streamlit application allows for bilingual conversation using speech recognition and translation.

## Installation

pip install -r requirements.txt



## Configuration
Microphone: Ensure your microphone settings are configured correctly.
Speaker: Set your speaker output according to the local machine and Microsoft Teams settings.